#
# spec file for package python-tox
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-tox
Version:        2.9.1
Release:        lp151.3.3
Summary:        Virtualenv-based automation of test activities
License:        MIT
Group:          Development/Languages/Python
Url:            http://tox.testrun.org/
Source:         https://files.pythonhosted.org/packages/source/t/tox/tox-%{version}.tar.gz
# Test requirements:
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pluggy >= 0.3.0}
BuildRequires:  %{python_module py >= 1.4.17}
BuildRequires:  %{python_module pytest >= 2.3.5}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module virtualenv >= 1.11.2}
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
BuildRequires:  unzip
Requires:       python-pluggy >= 0.3.0
Requires:       python-py >= 1.4.17
Requires:       python-virtualenv >= 1.11.2
Requires(post):   update-alternatives
Requires(postun): update-alternatives
%ifpython3
Provides:       tox = %{version}
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
Tox as is a generic virtualenv management and test command line tool you can
use for:

* checking your package installs correctly with different
  Python versions and interpreters

* running your tests in each of the
  environments, configuring your test tool of choice

* acting as a frontend to Continuous Integration
  servers, greatly reducing boilerplate and merging
  CI and shell-based testing.

%package -n %{name}-doc
Summary:        Documentation for tox, a virtualenv-based test automation
Group:          Development/Languages/Python
Recommends:     %{python_module tox = %{version}}
Provides:       %{python_module tox-doc = %{version}}

%description -n %{name}-doc
Tox as is a generic virtualenv management and test command line tool you can
use for:

* checking your package installs correctly with different
  Python versions and interpreters

* running your tests in each of the
  environments, configuring your test tool of choice

* acting as a frontend to Continuous Integration
  servers, greatly reducing boilerplate and merging
  CI and shell-based testing.

This is the HTML documentation for tox package.

%prep
%setup -q -n tox-%{version}

%build
%python_build
python3 setup.py build_sphinx && rm -r doc/build/html/.buildinfo # Generate HTML documentation

%install
%python_install
for B in tox tox-quickstart ; do
    %python_clone -a %{buildroot}%{_bindir}/$B
done

%check
%{python_expand # okay
$python -m virtualenv env-%{$python_bin_suffix} --system-site-packages
. env-%{$python_bin_suffix}/bin/activate
$python setup.py install
# run test_config separately because it does something to other tests
$python -m pytest tests/test_config.py
# skip also cmdline tests, they are slow and mostly broken in our environment
$python -m pytest tests -k "not test_config and not test_z_cmdline"
deactivate
}

%post
%python_install_alternative tox tox-quickstart

%postun
%python_uninstall_alternative tox

%files %{python_files}
%defattr(-,root,root,-)
%doc LICENSE README.rst CHANGELOG.rst
%python_alternative %{_bindir}/tox
%python_alternative %{_bindir}/tox-quickstart
%{python_sitelib}/tox-%{version}-py%{python_version}.egg-info
%{python_sitelib}/tox

%files -n %{name}-doc
%doc LICENSE README.rst doc/build/html

%changelog
* Fri Dec 22 2017 dimstar@opensuse.org
- Fix generation of html documentation.
* Sat Sep 30 2017 arun@gmx.de
- specfile:
  * change CHANGELOG -> CHANGELOG.rst
  * added setuptools_scm requirement
- update to version 2.9.1:
  * Misc
    + integrated new release process and fixed changelog rendering for
    pypi.org - by @obestwalter.
- changes from version 2.9.0:
  * Features
    + tox --version now shows information about all registered plugins
  - by @obestwalter (#544)
  * Bugfixes
    + skip_install overrides usedevelop (usedevelop is an option to
    choose the installation type if the package is installed and
    skip_install determines if it should be installed at all) - by
    @ferdonline (#571)
  * Misc
    + #635 inherit from correct exception - by @obestwalter (#635).
    + spelling and escape sequence fixes - by @scoop (#637 and #638).
    + add a badge to show build status of documentation on
    readthedocs.io - by @obestwalter.
  * Improved Documentation
    + add towncrier to allow adding changelog entries with the pull
    requests without generating merge conflicts; with this release
    notes are now grouped into four distinct collections: Features,
    Bugfixes, Improved Documentation and Deprecations and
    Removals. (#614)
- changes from version 2.8.2:
  * #466: stop env var leakage if popen failed with resultjson or
    redirect
- changes from version 2.8.1:
  * pull request 599: fix problems with implementation of
    [#515]. Substitutions from other sections were not made anymore if
    they were not in envlist. Thanks to Clark Boylan (@cboylan) for
    helping to get this fixed (pull request 597).
- changes from version 2.8.0:
  * #276: Remove easy_install from docs (TL;DR: use pip). Thanks
    Martin Andrysík (@sifuraz).
  * #301: Expand nested substitutions in tox.ini. Thanks
    @vlaci. Thanks to Eli Collins (@eli-collins) for creating a
    reproducer.
  * #315: add --help and --version to helptox-quickstart. Thanks
    @vlaci.
  * #326: Fix OSError 'Not a directory' when creating env on Jython
    2.7.0. Thanks Nick Douma (@LordGaav).
  * #429: Forward MSYSTEM by default on Windows. Thanks Marius
    Gedminas (@mgedmin) for reporting this.
  * #449: add multi platform example to the docs. Thanks Aleks Bunin
    (@sashkab) and @rndr.
  * #474: Start using setuptools_scm for tag based versioning.
  * #484: Renamed py.test to pytest throughout the project. Thanks
    Slam (@3lnc).
  * #504: With -a: do not show additional environments header if there
    are none. Thanks @rndr.
  * #515: Don't require environment variables in test environments
    where they are not used. Thanks André Caron (@AndreLouisCaron).
  * #517: Forward NUMBER_OF_PROCESSORS by default on Windows to fix
    multiprocessor.cpu_count(). Thanks André Caron
    (@AndreLouisCaron).
  * #518: Forward USERPROFILE by default on Windows. Thanks André
    Caron (@AndreLouisCaron).
  * pull request 528: Fix some of the warnings displayed by pytest
    3.1.0. Thanks Bruno Oliveira (@nicoddemus).
  * pull request 547: Add regression test for #137. Thanks Martin
    Andrysík (@sifuraz).
  * pull request 553: Add an XFAIL test to reproduce upstream bug
    [#203]. Thanks Bartolomé Sánchez Salado (@bartsanchez).
  * pull request 556: Report more meaningful errors on why virtualenv
    creation failed. Thanks @vlaci. Also thanks to Igor Sadchenko
    (@igor-sadchenko) for pointing out a problem with that PR before
    it hit the masses ☺
  * pull request 575: Add announcement doc to end all announcement
    docs (using only CHANGELOG and Github issues since 2.5 already).
  * pull request 580: Do not ignore Sphinx warnings anymore. Thanks
    Bernát Gábor (@gaborbernat).
  * pull request 585: Expand documentation to explain pass through of
    flags from deps to pip (e.g. -rrequirements.txt,
  - cconstraints.txt). Thanks Alexander Loechel (@loechel).
  * pull request 588: Run pytest wit xfail_strict and adapt affected
    tests.
* Sat May  6 2017 toddrme2178@gmail.com
- Only one package should provide "tox".
* Fri Apr  7 2017 jmatejek@suse.com
- update for singlespec
- improve test runner, drop tox-disable-env-tests.patch
- split off common python-tox-doc subpackage
- update to 2.7.0
  * improve environment information for users
  * add "alwayscopy" config option
  * slightly backwards-incompatible fix for {posargs} substitution
  * add Python 3.6 and 3.7 support
  * more bugfixes, see CHANGELOG for more details
* Mon Feb 20 2017 dmueller@suse.com
- add a "tox" provides that helps finding it for non-SUSE users
* Wed Apr  6 2016 hpj@urpla.net
- remove failing test: test_force_dep_with_url; requires network
  update tox-disable-env-tests.patch
* Mon Feb  8 2016 tbechtold@suse.com
- update to 2.3.1:
  * fix issue294: re-allow cross-section substitution for setenv.
  * DEPRECATE use of "indexservers" in tox.ini.  It complicates
    the internal code and it is recommended to rather use the
    devpi system for managing indexes for pip.
  * fix issue285: make setenv processing fully lazy to fix regressions
    of tox-2.2.X and so that we can now have testenv attributes like
    "basepython" depend on environment variables that are set in
    a setenv section. Thanks Nelfin for some tests and initial
    work on a PR.
  * allow "#" in commands.  This is slightly incompatible with commands
    sections that used a comment after a "\" line continuation.
    Thanks David Stanek for the PR.
  * fix issue289: fix build_sphinx target, thanks Barry Warsaw.
  * fix issue252: allow environment names with special characters.
    Thanks Julien Castets for initial PR and patience.
  * introduce experimental tox_testenv_create(venv, action) and
    tox_testenv_install_deps(venv, action) hooks to allow
    plugins to do additional work on creation or installing
    deps.  These hooks are experimental mainly because of
    the involved "venv" and session objects whose current public
    API is not fully guranteed.
  * internal: push some optional object creation into tests because
    tox core doesn't need it.
  * fix bug where {envdir} substitution could not be used in setenv
    if that env value is then used in {basepython}. Thanks Florian Bruhin.
  * fix issue265 and add LD_LIBRARY_PATH to passenv on linux by default
    because otherwise the python interpreter might not start up in
    certain configurations (redhat software collections).  Thanks David Riddle.
  * fix issue246: fix regression in config parsing by reordering
    such that {envbindir} can be used again in tox.ini. Thanks Olli Walsh.
  * fix issue99: the {env:...} substitution now properly uses environment
    settings from the ``setenv`` section. Thanks Itxaka Serrano.
  * fix issue281: make --force-deps work when urls are present in
    dependency configs.  Thanks Glyph Lefkowitz for reporting.
  * fix issue174: add new ``ignore_outcome`` testenv attribute which
    can be set to True in which case it will produce a warning instead
    of an error on a failed testenv command outcome.
    Thanks Rebecka Gulliksson for the PR.
  * fix issue280: properly skip missing interpreter if
    {envsitepackagesdir} is present in commands. Thanks BB:ceridwenv
- Refresh tox-disable-env-tests.patch
* Wed Sep 16 2015 rhafer@suse.com
- (Build)Require python-pluggy
- refreshed tox-disable-env-tests.patch
- Update to 2.1.1:
  * fix platform skipping for detox
  * report skipped platforms as skips in the summary
- additional changes from version 2.1.0
  * fix issue258, fix issue248, fix issue253: for non-test commands
    (installation, venv creation) we pass in the full invocation environment.
  * remove experimental --set-home option which was hardly used and
    hackily implemented (if people want home-directory isolation we should
    figure out a better way to do it, possibly through a plugin)
  * fix issue259: passenv is now a line-list which allows to intersperse
    comments.  Thanks stefano-m.
  * allow envlist to be a multi-line list, to intersperse comments
    and have long envlist settings split more naturally.  Thanks Andre Caron.
  * introduce a TOX_TESTENV_PASSENV setting which is honored
    when constructing the set of environment variables for test environments.
    Thanks Marc Abramowitz for pushing in this direction.
- additional changes from version 2.0.2
  * fix issue247: tox now passes the LANG variable from the tox invocation
    environment to the test environment by default.
  * add SYSTEMDRIVE into default passenv on windows to allow pip6 to work.
    Thanks Michael Krause.
- additional changes from version 2.0.1
  * fix wheel packaging to properly require argparse on py26.
- additional changes from version 2.0.0
  * (new) introduce environment variable isolation:
    tox now only passes the PATH and PIP_INDEX_URL variable from the tox
    invocation environment to the test environment and on Windows
    also ``SYSTEMROOT``, ``PATHEXT``, ``TEMP`` and ``TMP`` whereas
    on unix additionally ``TMPDIR`` is passed.  If you need to pass
    through further environment variables you can use the new ``passenv`` setting,
    a space-separated list of environment variable names.  Each name
    can make use of fnmatch-style glob patterns.  All environment
    variables which exist in the tox-invocation environment will be copied
    to the test environment.
  * a new ``--help-ini`` option shows all possible testenv settings and
    their defaults.
  * (new) introduce a way to specify on which platform a testenvironment is to
    execute: the new per-venv "platform" setting allows to specify
    a regular expression which is matched against sys.platform.
    If platform is set and doesn't match the platform spec in the test
    environment the test environment is ignored, no setup or tests are attempted.
  * (new) add per-venv "ignore_errors" setting, which defaults to False.
    If ``True``, a non-zero exit code from one command will be ignored and
    further commands will be executed (which was the default behavior in tox <
    2.0).  If ``False`` (the default), then a non-zero exit code from one command
    will abort execution of commands for that environment.
  * show and store in json the version dependency information for each venv
  * remove the long-deprecated "distribute" option as it has no effect these days.
  * fix issue233: avoid hanging with tox-setuptools integration example. Thanks simonb.
  * fix issue120: allow substitution for the commands section.  Thanks
    Volodymyr Vitvitski.
  * fix issue235: fix AttributeError with --installpkg.  Thanks
    Volodymyr Vitvitski.
  * tox has now somewhat pep8 clean code, thanks to Volodymyr Vitvitski.
  * fix issue240: allow to specify empty argument list without it being
    rewritten to ".".  Thanks Daniel Hahler.
  * introduce experimental (not much documented yet) plugin system
    based on pytest's externalized "pluggy" system.
    See tox/hookspecs.py for the current hooks.
  * introduce parser.add_testenv_attribute() to register an ini-variable
    for testenv sections.  Can be used from plugins through the
    tox_add_option hook.
  * rename internal files -- tox offers no external API except for the
    experimental plugin hooks, use tox internals at your own risk.
  * DEPRECATE distshare in documentation
* Sat May  2 2015 benoit.monin@gmx.fr
- update to version 1.9.2:
  * backout ability that --force-deps substitutes name/versions in
    requirement files due to various issues. This fixes issue228,
    fixes issue230, fixes issue231 which popped up with 1.9.1.
- additional changes from version 1.9.1:
  * use a file instead of a pipe for command output in
    "--result-json". Fixes some termination issues with python2.6.
  * allow --force-deps to override dependencies in "-r"
    requirements files.  Thanks Sontek for the PR.
  * fix issue227: use "-m virtualenv" instead of "-mvirtualenv" to
    make it work with pyrun.  Thanks Marc-Andre Lemburg.
- additional changes from version 1.9.0:
  * fix issue193: Remove ``--pre`` from the default
    ``install_command``; by default tox will now only install final
    releases from PyPI for unpinned dependencies. Use ``pip_pre =
    true`` in a testenv or the ``--pre`` command-line option to
    restore the previous behavior.
  * fix issue199: fill resultlog structure ahead of virtualenv
    creation
  * refine determination if we run from Jenkins, thanks Borge Lanes.
  * echo output to stdout when ``--report-json`` is used
  * fix issue11: add a ``skip_install`` per-testenv setting which
    prevents the installation of a package. Thanks Julian Krause.
  * fix issue124: ignore command exit codes; when a command has a
    "-" prefix, tox will ignore the exit code of that command
  * fix issue198: fix broken envlist settings, e.g.
    {py26,py27}{-lint,}
  * fix issue191: lessen factor-use checks
- additional changes from version 1.8.1:
  * fix issue190: allow setenv to be empty.
  * allow escaping curly braces with "\".  Thanks Marc Abramowitz
    for the PR.
  * allow "." names in environment names such that "py27-django1.7"
    is a valid environment name.  Thanks Alex Gaynor and Alex
    Schepanovski.
  * report subprocess exit code when execution fails.  Thanks
    Marius Gedminas.
- additional changes from version 1.8.0:
  * new multi-dimensional configuration support.  Many thanks to
    Alexander Schepanovski for the complete PR with docs. And to
    Mike Bayer and others for testing and feedback.
  * fix issue148: remove "__PYVENV_LAUNCHER__" from os.environ when
    starting subprocesses. Thanks Steven Myint.
  * fix issue152: set VIRTUAL_ENV when running test commands,
    thanks Florian Ludwig.
  * better report if we can't get version_info from an interpreter
    executable. Thanks Floris Bruynooghe.
- update project URL
- refresh tox-disable-env-tests.patch
* Mon Aug 25 2014 aj@suse.com
- Update to version 1.7.2:
  * fix issue150: parse {posargs} more like we used to do it pre
    1.7.0.
  * fix issue59: add a config variable skip-missing-interpreters as
    well as command line option --skip-missing-interpreters
  * fix issue164: better traceback info in case of failing test commands
  * support optional env variable substitution.
  * limit python hashseed to 1024 on Windows to prevent possible
    memory errors.
* Thu Jul  3 2014 speilicke@suse.com
- Update to version 1.7.1:
  - fix issue162: don't list python 2.5 as compatibiliy/supported
  - fix issue158 and fix issue155: windows/virtualenv properly works now:
    call virtualenv through "python -m virtualenv" with the same
    interpreter which invoked tox.  Thanks Chris Withers, Ionel Maries Cristian.
- Add tox-disable-env-tests.patch: Disable tests that need network-access
  and that depend on /usr/bin/tox (which is only added via u-a in %%post)
- Remove tox-disable-network-accessing-tests.patch: Obsoleted by the above patch
- Implement update-alternatives to allow parallel installation with python3-tox
* Thu Sep 19 2013 speilicke@suse.com
- (Build)Require python-argparse on SLE
* Thu Sep  5 2013 speilicke@suse.com
- Update to version 1.6.0:
  + fix issue119: {envsitepackagesdir} is now correctly computed and has
    a better test to prevent regression.
  + fix issue116: make 1.6 introduced behaviour of changing to a
    per-env HOME directory during install activities dependent
    on "--set-home" for now.  Should re-establish the old behaviour
    when no option is given.
  + fix issue118: correctly have two tests use realpath(). Thanks Barry
    Warsaw.
  + fix test runs on environments without a home directory
    (in this case we use toxinidir as the homedir)
  + fix issue117: python2.5 fix: don't use ``--insecure`` option because
    its very existence depends on presence of "ssl".  If you
    want to support python2.5/pip1.3.1 based test environments you need
    to install ssl and/or use PIP_INSECURE=1 through ``setenv``. section.
  + fix issue102: change to {toxinidir} when installing dependencies.
    this allows to use relative path like in "-rrequirements.txt".
- Changes from version 1.6.0:
  + fix issue35: add new EXPERIMENTAL "install_command" testenv-option to
    configure the installation command with options for dep/pkg install.
    Thanks Carl Meyer for the PR and docs.
  + fix issue91: python2.5 support by vendoring the virtualenv-1.9.1
    script and forcing pip<1.4. Also the default [py25] environment
    modifies the default installer_command (new config option)
    to use pip without the "--pre" option which was introduced
    with pip-1.4 and is now required if you want to install non-stable
    releases.  (tox defaults to install with "--pre" everywhere).
  + during installation of dependencies HOME is now set to a pseudo
    location ({envtmpdir}/pseudo-home).  If an index url was specified
    a .pydistutils.cfg file will be written with an index_url setting
    so that packages defining ``setup_requires`` dependencies will not
    silently use your HOME-directory settings or https://pypi.python.org.
  + fix issue1: empty setup files are properly detected, thanks Anthon van
    der Neuth
  + remove toxbootstrap.py for now because it is broken.
  + fix issue109 and fix issue111: multiple "-e" options are now combined
    (previously the last one would win). Thanks Anthon van der Neut.
  + add --result-json option to write out detailed per-venv information
    into a json report file to be used by upstream tools.
  + add new config options ``usedevelop`` and ``skipsdist`` as well as a
    command line option ``--develop`` to install the package-under-test in develop mode.
    thanks Monty Tailor for the PR.
  + always unset PYTHONDONTWRITEBYTE because newer setuptools doesn't like it
  + if a HOMEDIR cannot be determined, use the toxinidir.
  + refactor interpreter information detection to live in new
    tox/interpreters.py file, tests in tests/test_interpreters.py.
- Add tox-disable-network-accessing-tests.patch: Disable tests that insist on
  downloading dependencies over network
- Run testsuite
* Tue Jun 25 2013 dmueller@suse.com
- update to 1.5.0:
  - fix issue104: use setuptools by default, instead of distribute,
  now that setuptools has distribute merged.
  - make sure test commands are searched first in the virtualenv
  - re-fix issue2 - add whitelist_externals to be used in ``[testenv*]``
  sections, allowing to avoid warnings for commands such as ``make``,
  used from the commands value.
  - fix issue97 - allow substitutions to reference from other sections
  (thanks Krisztian Fekete)
  - fix issue92 - fix {envsitepackagesdir} to actually work again
  - show (test) command that is being executed, thanks
  Lukasz Balcerzak
  - re-license tox to MIT license
  - depend on virtualenv-1.9.1
  - rename README.txt to README.rst to make bitbucket happier
* Mon Jun 17 2013 speilicke@suse.com
- Only require argparse on SLE, it's part of Python-2.7
* Sun Apr 21 2013 toms@opensuse.org
- Update to version 1.4.3:
  See http://testrun.org/tox/latest//changelog.html for more details
- SPEC file: Added bcond with test to prepare testing. Doesn't work
  yet, but can be improved
* Thu Jul 26 2012 saschpe@suse.de
- Update to version 1.4.2:
  + fix some tests which fail if /tmp is a symlink to some other place
  + "python setup.py test" now runs tox tests via tox :)
    also added an example on how to do it for your project.
- Changes from version 1.4.1:
  + fix issue41 better quoting on windows - you can now use "<" and ">" in
    deps specifications, thanks Chris Withers for reporting
* Fri Jun 22 2012 saschpe@suse.de
- Update to version 1.4:
  + fix issue26 - no warnings on absolute or relative specified paths for commands
  + fix issue33 - commentchars are ignored in key-value settings allowing
    for specifying commands like: python -c "import sys ; print sys"
    which would formerly raise irritating errors because the ";"
    was considered a comment
  + tweak and improve reporting
  + refactor reporting and virtualenv manipulation
    to be more accessible from 3rd party tools
  + support value substitution from other sections
    with the {[section]key} syntax
  + fix issue29 - correctly point to pytest explanation
    for importing modules fully qualified
  + fix issue32 - use --system-site-packages and don't pass --no-site-packages
  + add python3.3 to the default env list, so early adopters can test
  + drop python2.4 support (you can still have your tests run on
    python-2.4, just tox itself requires 2.5 or higher.
* Tue Feb 21 2012 saschpe@suse.de
- Don't use nose, but custom script to run testsuite
* Mon Feb 20 2012 saschpe@gmx.de
- Initial version
